Notatka
Dostęp do tej strony wymaga autoryzacji. Może spróbować zalogować się lub zmienić katalogi.
Dostęp do tej strony wymaga autoryzacji. Możesz spróbować zmienić katalogi.
Zarządzanie urządzeniami Azure Sphere.
| Operation | Opis |
|---|---|
| az sphere device rescan-attached | Pokaż liczbę dołączonych urządzeń. |
| az sphere device list-attached | Wyświetl listę wszystkich dołączonych urządzeń. |
| az sphere device show-attached | Pokaż szczegóły dołączonego urządzenia. |
| az sphere device list | Wyświetl listę wszystkich urządzeń w katalogu, produkcie lub grupie urządzeń. |
| az sphere device show-count | Pokaż liczbę urządzeń w katalogu, produkcie lub grupie urządzeń. |
| az sphere device show | Pokaż szczegóły istniejącego urządzenia w grupie zasobów i katalogu. |
| az sphere device assign | Przypisz urządzenie do grupy urządzeń w grupie zasobów i katalogu. |
| az sphere device unassign | Usuń przypisanie urządzenia do grupy urządzeń w grupie zasobów i katalogu. |
| az sphere device restart | Uruchom ponownie dołączone urządzenie. |
| oświadczenie dotyczące urządzenia az sphere | Przypisz urządzenie do grupy zasobów i katalogu. |
| az sphere device recover | Użyj trybu odzyskiwania, aby załadować nowe oprogramowanie układowe na dołączone urządzenie. |
| az sphere device show-os-version | Pokaż wersję systemu operacyjnego na dołączonym urządzeniu. |
| az sphere device show-deployment-status | Pokaż stan wdrożenia systemu operacyjnego na urządzeniu. |
| az sphere device enable-development | "Włącz urządzenie do programowania, włączając ładowanie bezpośrednie i debugowanie na dołączonym urządzeniu, a następnie przypisując je do grupy urządzeń, która wyłącza aktualizacje aplikacji z chmury. Domyślnie będzie to grupa urządzeń deweloperskich produktu urządzenia, ale można określić inne grupy urządzeń. Nie do użytku w środowisku produkcyjnym: więcej informacji znajduje się w https://aka.ms/AzureSphereManufacturing. |
| az sphere device enable-cloud-test | "Włącz urządzenie do testowania ładowania w chmurze, wyłączając programowanie i debugowanie na dołączonym urządzeniu, a następnie przypisując je do grupy urządzeń, która umożliwia aktualizacje aplikacji z chmury. Domyślnie będzie to grupa urządzeń testów terenowych dla produktu tego urządzenia, ale można również określić inne grupy urządzeń. Nie do stosowania w środowiskach produkcyjnych: więcej informacji można znaleźć w https://aka.ms/AzureSphereManufacturing. |
Komendy
az sphere device rescan-attached
Pokaż liczbę dołączonych urządzeń.
Wymagane parametry
| Parametr | Opis |
|---|---|
| --device -d | Urządzenie, na którym ma być uruchomione polecenie, gdy podłączone są liczne urządzenia. Określ identyfikator, adres IP lub identyfikator połączenia lokalnego dołączonego urządzenia. Wartości z: az sphere device list-attached. |
Examples
Pokaż liczbę dołączonych urządzeń.
az sphere device rescan-attached
az sphere device list-attached
Wyświetl listę wszystkich dołączonych urządzeń.
Wymagane parametry
| Parametr | Opis |
|---|---|
| --device -d | Urządzenie, na którym ma być uruchomione polecenie, gdy podłączone są liczne urządzenia. Określ identyfikator, adres IP lub identyfikator połączenia lokalnego dołączonego urządzenia. Wartości z: az sphere device list-attached. |
Examples
Wyświetl listę wszystkich dołączonych urządzeń.
az sphere device list-attached
az sphere device show-attached
Pokaż szczegóły dołączonego urządzenia.
Parametry opcjonalne
| Parametr | Opis |
|---|---|
| --device -d | Urządzenie, na którym ma być uruchomione polecenie, gdy podłączone są liczne urządzenia. Określ identyfikator, adres IP lub identyfikator połączenia lokalnego dołączonego urządzenia. Wartości z: az sphere device list-attached. |
Examples
Pokaż szczegóły dołączonego urządzenia.
az sphere device show-attached
Pokaż szczegóły określonego urządzenia.
az sphere device show-attached --device <DeviceIdValue>
az sphere device list
Wyświetl listę wszystkich urządzeń w katalogu, produkcie lub grupie urządzeń.
Wymagane parametry
| Parametr | Opis |
|---|---|
| --catalog -c | Wykaz Azure Sphere, w którym ma być wykonywana ta operacja. Określ nazwę katalogu Azure Sphere. Domyślny katalog Azure Sphere można skonfigurować przy użyciu az config set defaults.sphere.catalog=<name>. Wartości z: az sphere catalog list. |
| --resource-group -g | Nazwa grupy zasobów platformy Azure. Grupę domyślną można skonfigurować przy użyciu polecenia az config set defaults.group=<name>. Wartości z: az group list. |
Parametry opcjonalne
| Parametr | Opis |
|---|---|
| --product -p | Nazwa produktu. Wartości z: az sphere product list. |
| --device-group -dg | Nazwa grupy urządzeń. Wartości z: az sphere device-group list. |
Examples
Wyświetl listę wszystkich urządzeń w grupie zasobów i katalogu.
az sphere device list --resource-group MyResourceGroup --catalog MyCatalog
Wyświetl listę wszystkich urządzeń w grupie zasobów, katalogu i produkcie.
az sphere device list --resource-group MyResourceGroup --catalog MyCatalog --product MyProduct
Wyświetl listę wszystkich urządzeń w grupie zasobów, katalogu, produkcie i grupie urządzeń.
az sphere device list --resource-group MyResourceGroup --catalog MyCatalog --product MyProduct --device-group MyDeviceGroup
az sphere device show-count
Pokaż liczbę urządzeń w katalogu, produkcie lub grupie urządzeń.
Wymagane parametry
| Parametr | Opis |
|---|---|
| --catalog -c | Wykaz Azure Sphere, w którym ma być wykonywana ta operacja. Określ nazwę katalogu Azure Sphere. Domyślny katalog Azure Sphere można skonfigurować przy użyciu az config set defaults.sphere.catalog=<name>. Wartości pochodzą z: az sphere catalog list. |
| --resource-group -g | Nazwa grupy zasobów platformy Azure. Grupę domyślną można skonfigurować przy użyciu polecenia az config set defaults.group=<name>. Wartości z: az group list. |
Parametry opcjonalne
| Parametr | Opis |
|---|---|
| --product -p | Nazwa produktu. Wartości z: az sphere product list. |
| --device-group -dg | Nazwa grupy urządzeń. Wartości z: az sphere device-group list. |
Examples
Pokaż liczbę urządzeń w grupie zasobów i katalogu.
az sphere device show-count --resource-group MyResourceGroup --catalog MyCatalog
Pokaż liczbę urządzeń w grupie zasobów, katalogu i produkcie.
az sphere device show-count --resource-group MyResourceGroup --catalog MyCatalog --product MyProduct
Pokaż liczbę urządzeń w grupie zasobów, katalogu, produkcie i grupie urządzeń.
az sphere device show-count --resource-group MyResourceGroup --catalog MyCatalog --product MyProduct --device-group MyDeviceGroup
az sphere device show
Pokaż szczegóły istniejącego urządzenia w grupie zasobów i katalogu.
Wymagane parametry
| Parametr | Opis |
|---|---|
| --catalog -c | Wykaz Azure Sphere, w którym ma być wykonywana ta operacja. Określ nazwę katalogu Azure Sphere. Domyślny katalog Azure Sphere można skonfigurować przy użyciu az config set defaults.sphere.catalog=<name>. Wartości z: az sphere catalog list. |
| --resource-group -g | Nazwa grupy zasobów platformy Azure. Grupę domyślną można skonfigurować przy użyciu polecenia az config set defaults.group=<name>. Wartości z: az group list. |
Parametry opcjonalne
| Parametr | Opis |
|---|---|
| --device -d | Urządzenie, które ma być celem tego polecenia. Jest to wymagane, gdy żadne urządzenie lub wiele urządzeń nie są dołączone, aby uściślić, które urządzenie ma być docelowe. Jeśli urządzenie jest dołączone, możesz podać identyfikator urządzenia, adres IP lub identyfikator połączenia lokalnego. W przeciwnym razie musisz podać tylko identyfikator urządzenia. Wartości z: az sphere device list. |
Examples
Pokaż szczegóły urządzenia przy użyciu grupy zasobów, nazwy katalogu i identyfikatora urządzenia.
az sphere device show --resource-group MyResourceGroup --catalog MyCatalog --device <DeviceIdValue>
az sphere device assign
Przypisz urządzenie do grupy urządzeń w grupie zasobów i katalogu.
Wymagane parametry
| Parametr | Opis |
|---|---|
| --device -d | Urządzenie, do którego jest kierowane to polecenie. Jest to wymagane, gdy żadne urządzenie lub wiele urządzeń nie są dołączone, aby uściślić, które urządzenie ma być docelowe. Jeśli urządzenie jest dołączone, możesz podać identyfikator urządzenia, adres IP lub identyfikator połączenia lokalnego. W przeciwnym razie musisz podać tylko identyfikator urządzenia. Wartości pochodzą z: az sphere device list. |
| --target-product | Nazwa produktu docelowego. Wartości z: listy produktów Azure Sphere. |
| --target-device-group | Nazwa docelowej grupy urządzeń. Wartości pochodzą z: az sphere device-group list. |
| --catalog -c | Wykaz Azure Sphere, w którym ma być wykonywana ta operacja. Określ nazwę katalogu Azure Sphere. Domyślny katalog Azure Sphere można skonfigurować przy użyciu az config set defaults.sphere.catalog=<name>. Wartości pochodzą z: az sphere catalog list. |
| --resource-group -g | Nazwa grupy zasobów platformy Azure. Grupę domyślną można skonfigurować przy użyciu polecenia az config set defaults.group=<name>. Wartości z: az group list. |
Examples
Przypisz urządzenie przy użyciu grupy zasobów, nazwy katalogu, docelowej nazwy produktu, docelowej nazwy grupy urządzeń i identyfikatora urządzenia.
az sphere device assign --resource-group MyResourceGroup --catalog MyCatalog --target-product MyProduct --target-device-group MyCurrentDeviceGroup --device <DeviceIdValue>
az sphere device unassign
Usuń przypisanie urządzenia do grupy urządzeń w grupie zasobów i katalogu.
Wymagane parametry
| Parametr | Opis |
|---|---|
| --device -d | Urządzenie, do którego jest kierowane to polecenie. Jest to wymagane, gdy żadne urządzenie lub wiele urządzeń nie są dołączone, aby uściślić, które urządzenie ma być docelowe. Jeśli urządzenie jest dołączone, możesz podać identyfikator urządzenia, adres IP lub identyfikator połączenia lokalnego. W przeciwnym razie musisz podać tylko identyfikator urządzenia. Wartości z: az sphere device list. |
| --catalog -c | Wykaz Azure Sphere, w którym ma być wykonywana ta operacja. Określ nazwę katalogu Azure Sphere. Domyślny katalog Azure Sphere można skonfigurować przy użyciu az config set defaults.sphere.catalog=<name>. Wartości z: az sphere catalog list. |
| --resource-group -g | Nazwa grupy zasobów platformy Azure. Grupę domyślną można skonfigurować przy użyciu polecenia az config set defaults.group=<name>. Wartości z: az group list. |
Examples
Usuń przypisanie urządzenia przy użyciu grupy zasobów, nazwy katalogu i identyfikatora urządzenia.
az sphere device unassign --resource-group MyResourceGroup --catalog MyCatalog --device <DeviceIdValue>
az sphere device restart
Uruchom ponownie dołączone urządzenie.
Wymagane parametry
| Parametr | Opis |
|---|---|
| --catalog -c | Wykaz Azure Sphere, w którym ma być wykonywana ta operacja. Określ nazwę katalogu Azure Sphere. Domyślny katalog Azure Sphere można skonfigurować przy użyciu az config set defaults.sphere.catalog=<name>. Wartości z: az sphere catalog list. |
| --resource-group -g | Nazwa grupy zasobów platformy Azure. Grupę domyślną można skonfigurować przy użyciu polecenia az config set defaults.group=<name>. Wartości z: az group list. |
Parametry opcjonalne
| Parametr | Opis |
|---|---|
| --device -d | Urządzenie, na którym ma być uruchomione polecenie, gdy podłączone są liczne urządzenia. Określ identyfikator, adres IP lub identyfikator połączenia lokalnego dołączonego urządzenia. Wartości z: az sphere device list-attached. |
Examples
Uruchom ponownie dołączone urządzenie.
az sphere device restart
Uruchom ponownie określone urządzenie.
az sphere device restart --device <DeviceIdValue>
roszczenie dotyczące urządzenia AZ Sphere
Przypisz urządzenie do grupy zasobów i katalogu.
Wymagane parametry
| Parametr | Opis |
|---|---|
| --catalog -c | Wykaz Azure Sphere, w którym ma być wykonywana ta operacja. Określ nazwę katalogu Azure Sphere. Domyślny katalog Azure Sphere można skonfigurować przy użyciu az config set defaults.sphere.catalog=<name>. Wartości z: az sphere catalog list. |
| --resource-group -g | Nazwa grupy zasobów platformy Azure. Grupę domyślną można skonfigurować przy użyciu polecenia az config set defaults.group=<name>. Wartości z: az group list. |
Parametry opcjonalne
| Parametr | Opis |
|---|---|
| --device -d | Urządzenie, do którego jest kierowane to polecenie. Jest to wymagane, gdy żadne urządzenie lub wiele urządzeń nie są dołączone, aby uściślić, które urządzenie ma być docelowe. Jeśli urządzenie jest dołączone, możesz podać identyfikator urządzenia, adres IP lub identyfikator połączenia lokalnego. W przeciwnym razie musisz podać tylko identyfikator urządzenia. Wartości z: az sphere device list. |
| --product -p | Nazwa produktu, w którym ma być zgłoszone urządzenie. Wartości z: listy produktów Azure Sphere. |
| --device-group -dg | Nazwa grupy urządzeń, w której ma być zgłoszone urządzenie. Wartości pochodzą z: az sphere device-group list. |
Examples
Przejmij urządzenie przy użyciu grupy zasobów, nazwy katalogu i identyfikatora urządzenia.
az sphere device claim --resource-group MyResourceGroup --catalog MyCatalog --device <DeviceIdValue>
Przypisz urządzenie za pomocą grupy zasobów, nazwy katalogu, nazwy produktu, nazwy grupy urządzeń i identyfikatora urządzenia.
az sphere device claim --resource-group MyResourceGroup --catalog MyCatalog --product MyProduct --device-group MyDeviceGroup --device <DeviceIdValue>
az sphere device recover
Użyj trybu odzyskiwania, aby załadować nowe oprogramowanie układowe na dołączone urządzenie.
Wymagane parametry
| Parametr | Opis |
|---|---|
| --catalog -c | Wykaz Azure Sphere, w którym ma być wykonywana ta operacja. Określ nazwę katalogu Azure Sphere. Domyślny katalog Azure Sphere można skonfigurować przy użyciu az config set defaults.sphere.catalog=<name>. Wartości z: az sphere catalog list. |
| --resource-group -g | Nazwa grupy zasobów platformy Azure. Grupę domyślną można skonfigurować przy użyciu polecenia az config set defaults.group=<name>. Wartości z: az group list. |
Parametry opcjonalne
| Parametr | Opis |
|---|---|
| --device -d | Urządzenie, na którym ma być uruchomione polecenie, gdy podłączone są liczne urządzenia. Określ identyfikator, adres IP lub identyfikator połączenia lokalnego dołączonego urządzenia. Wartości z: az sphere device list-attached. |
| --Możliwości | Nazwa pliku obrazu funkcji urządzenia, który ma zostać zastosowany do urządzenia podczas procesu odzyskiwania. (Path). |
| --Obrazów | Folder zawierający pakiety obrazów do zapisu na urządzeniu. Jeśli nie określono inaczej, pobierane i używane są najnowsze obrazy systemu operacyjnego. (Path). |
Examples
Odzyskiwanie dołączonego urządzenia.
az sphere device recover
Odzyskaj dołączone urządzenie z określonymi możliwościami i obrazami.
az sphere device recover --capability myCapability.cap --images myImagesFolder
az sphere device show-os-version
Pokaż wersję systemu operacyjnego na dołączonym urządzeniu.
Wymagane parametry
| Parametr | Opis |
|---|---|
| --catalog -c | Wykaz Azure Sphere, w którym ma być wykonywana ta operacja. Określ nazwę katalogu Azure Sphere. Domyślny katalog Azure Sphere można skonfigurować przy użyciu az config set defaults.sphere.catalog=<name>. Wartości z: az sphere catalog list. |
| --resource-group -g | Nazwa grupy zasobów platformy Azure. Grupę domyślną można skonfigurować przy użyciu polecenia az config set defaults.group=<name>. Wartości z: az group list. |
Parametry opcjonalne
| Parametr | Opis |
|---|---|
| --device -d | Urządzenie, na którym ma być uruchomione polecenie, gdy podłączone są liczne urządzenia. Określ identyfikator, adres IP lub identyfikator połączenia lokalnego dołączonego urządzenia. Wartości z: az sphere device list-attached. |
Examples
Pokaż wersję systemu operacyjnego na dołączonym urządzeniu.
az sphere device show-os-version
Pokaż wersję systemu operacyjnego na określonym urządzeniu.
az sphere device show-os-version --device <DeviceIdValue>
az sphere device show-deployment-status
Pokaż stan wdrożenia systemu operacyjnego na urządzeniu.
Wymagane parametry
| Parametr | Opis |
|---|---|
| --catalog -c | Wykaz Azure Sphere, w którym ma być wykonywana ta operacja. Określ nazwę katalogu Azure Sphere. Domyślny katalog Azure Sphere można skonfigurować przy użyciu az config set defaults.sphere.catalog=<name>. Wartości z: az sphere catalog list. |
| --resource-group -g | Nazwa grupy zasobów platformy Azure. Grupę domyślną można skonfigurować przy użyciu polecenia az config set defaults.group=<name>. Wartości z: az group list. |
Parametry opcjonalne
| Parametr | Opis |
|---|---|
| --device -d | Urządzenie, na którym ma być uruchomione polecenie, gdy podłączone są liczne urządzenia. Określ identyfikator, adres IP lub identyfikator połączenia lokalnego dołączonego urządzenia. Wartości z: az sphere device list-attached. |
Examples
Pokaż stan wdrożenia systemu operacyjnego przy użyciu grupy zasobów, nazwy katalogu i identyfikatora urządzenia.
az sphere device show-deployment-status --resource-group MyResourceGroup --catalog MyCatalog --device <DeviceIdValue>
az sphere device enable-development
"Włącz urządzenie do programowania, włączając ładowanie bezpośrednie i debugowanie na dołączonym urządzeniu, a następnie przypisując je do grupy urządzeń, która wyłącza aktualizacje aplikacji z chmury. Domyślnie będzie to grupa urządzeń deweloperskich produktu urządzenia, ale można określić inne grupy urządzeń. Nie do użytku w środowiskach produkcyjnych: więcej informacji można znaleźć w https://aka.ms/AzureSphereManufacturing.
Wymagane parametry
| Parametr | Opis |
|---|---|
| --catalog -c | Wykaz Azure Sphere, w którym ma być wykonywana ta operacja. Określ nazwę katalogu Azure Sphere. Domyślny katalog Azure Sphere można skonfigurować przy użyciu az config set defaults.sphere.catalog=<name>. Wartości z: az sphere catalog list. |
| --resource-group -g | Nazwa grupy zasobów platformy Azure. Grupę domyślną można skonfigurować przy użyciu polecenia az config set defaults.group=<name>. Wartości z: az group list. |
Parametry opcjonalne
| Parametr | Opis |
|---|---|
| --device -d | Urządzenie, na którym ma być uruchomione polecenie, gdy podłączone są liczne urządzenia. Określ identyfikator, adres IP lub identyfikator połączenia lokalnego dołączonego urządzenia. Wartości z: az sphere device list-attached. |
| --enable-rt-core-debugowanie -r | Zainstaluj sterowniki wymagane do debugowania aplikacji działających na rdzeniu czasu rzeczywistego. Wymaga uprawnień administratora. |
| --product -p | Nazwa produktu docelowego. Urządzenie zostanie przypisane do domyślnej grupy urządzeń deweloperskich wybranego produktu, chyba że zostanie również określona grupa urządzeń. Wartości z: az sphere product list. |
| --device-group -dg | Nazwa grupy urządzeń, do której zostanie przypisane urządzenie. Domyślnie jest to grupa urządzeń deweloperskich produktu. Wartości z: az sphere device-group list. |
Examples
Włącz urządzenie do programowania, włączając ładowanie bezpośrednie i debugowanie przy użyciu grupy zasobów, nazwy katalogu, identyfikatora urządzenia i domyślnej grupy urządzeń deweloperskich.
az sphere device enable-development --resource-group MyResourceGroup --catalog MyCatalog --device <DeviceIdValue>
Włącz urządzenie do programowania, włączając ładowanie bezpośrednie i debugowanie przy użyciu grupy zasobów, nazwy katalogu, nazwy produktu, nazwy grupy urządzeń i identyfikatora urządzenia.
az sphere device enable-development --resource-group MyResourceGroup --catalog MyCatalog --product MyProduct --device-group MyDeviceGroup --device <DeviceIdValue>
az sphere device enable-cloud-test
"Włącz urządzenie do testowania ładowania w chmurze, wyłączając programowanie i debugowanie na dołączonym urządzeniu, a następnie przypisując je do grupy urządzeń, która umożliwia aktualizacje aplikacji z chmury. Domyślnie będzie to grupa urządzeń do testów terenowych dla produktu tego urządzenia, ale można też określić inne grupy urządzeń. Nie do użytku w środowiskach produkcyjnych: więcej informacji można znaleźć tutaj https://aka.ms/AzureSphereManufacturing.
Wymagane parametry
| Parametr | Opis |
|---|---|
| --catalog -c | Wykaz Azure Sphere, w którym ma być wykonywana ta operacja. Określ nazwę katalogu Azure Sphere. Domyślny katalog Azure Sphere można skonfigurować przy użyciu az config set defaults.sphere.catalog=<name>. Wartości z: az sphere catalog list. |
| --resource-group -g | Nazwa grupy zasobów platformy Azure. Grupę domyślną można skonfigurować przy użyciu polecenia az config set defaults.group=<name>. Wartości z: az group list. |
Parametry opcjonalne
| Parametr | Opis |
|---|---|
| --device -d | Urządzenie, na którym ma być uruchomione polecenie, gdy podłączone są liczne urządzenia. Określ identyfikator, adres IP lub identyfikator połączenia lokalnego dołączonego urządzenia. Wartości z: az sphere device list-attached. |
| --product -p | Nazwa produktu docelowego. Urządzenie zostanie przypisane do domyślnej grupy urządzeń testowych pól wybranego produktu, chyba że określono również grupę urządzeń. Wartości z: az sphere product list. |
| --device-group -dg | Nazwa grupy urządzeń, do której zostanie przypisane urządzenie. Domyślnie jest to grupa urządzeń Field Test dla tego produktu. Wartości z: az sphere device-group list. |
Examples
Włącz urządzenie do testowania chmury przy użyciu grupy zasobów, nazwy katalogu, identyfikatora urządzenia i domyślnej grupy urządzeń testowych pól.
az sphere device enable-cloud-test --resource-group MyResourceGroup --catalog MyCatalog --device <DeviceIdValue>
Włącz urządzenie do testowania chmury przy użyciu grupy zasobów, nazwy katalogu, nazwy produktu, nazwy grupy urządzeń i identyfikatora urządzenia.
az sphere device enable-cloud-test --resource-group MyResourceGroup --catalog MyCatalog --product MyProduct --device-group MyDeviceGroup --device <DeviceIdValue>